@@ -5,15 +5,16 @@
 #' @description
 #' \code{copy*Repo} copies artifacts from one \code{Repository} into another \code{Repository}.
 #' It adds new files to existing \code{gallery} folder in \code{repoTo} \code{Repository}.
-#' \code{copyLocalRepo} copies local \code{Repository} while \code{copyGithubRepo} copies
-#' Github \code{Repository}. 
+#' \code{copyLocalRepo} copies local \code{Repository} while \code{copyRemoteRepo} copies
+#' remote \code{Repository}. 
 #' 
 #' @details
-#' Functions \code{copyLocalRepo} and \code{copyGithubRepo} copy artifacts from the
-#' archivist's Repositories stored in a local folder or on the Github. 
+#' Functions \code{copyLocalRepo} and \code{copyRemoteRepo} copy artifacts from the
+#' archivist's Repositories stored in a local folder or on the Remote. 
 #' Both of them use \code{md5hashes} of artifacts which are to be copied 
 #' in \code{md5hashes} parameter. For more information about \code{md5hash} see \link{md5hash}.
 #'
+#' @param repoType A character containing a type of the remote repository. Currently it can be 'Remote' or 'bitbucket'.
 #' @param repoFrom While copying local repository. A character that specifies
 #' the directory of the Repository from which
 #' artifacts will be copied. If it is set to \code{NULL} (by default),
@@ -22,28 +23,28 @@
 #' @param repoTo A character that specifies the directory of the Repository into which
 #' artifacts will be copied.
 #' 
-#' @param md5hashes A character vector containing \code{md5hashes} of artifacts to be copied.
+#' @param md5hashes A character vector containing \code{md5hashes} of artifacts to be copied. 
 #' 
-#' @param repo While coping the Github repository. A character containing a name of the
-#' Github repository on which the "\code{repoFrom}" - Repository is archived.
+#' @param repo While coping the remote repository. A character containing a name of the
+#' remote repository on which the "\code{repoFrom}" - Repository is archived.
 #' By default set to \code{NULL} - see \code{Note}.
 #' 
-#' @param user While coping the Github repository. A character containing a name
-#' of the Github user on whose account the "\code{repoFrom}" - Repository is created.
+#' @param user While coping the remote repository. A character containing a name
+#' of the remote user on whose account the "\code{repoFrom}" - Repository is created.
 #' By default set to \code{NULL} - see \code{Note}.
 #' 
-#' @param branch While coping with the Github repository. A character containing a name of 
-#' Github Repository's branch on which the "\code{repoFrom}" - Repository is archived.
+#' @param branch While coping with the remote repository. A character containing a name of 
+#' Remote Repository's branch on which the "\code{repoFrom}" - Repository is archived.
 #' Default \code{branch} is \code{master}.
 #'
-#' @param repoDirGit While working with the Github repository. A character containing a name of
-#' a directory on the Github repository on which the "\code{repoFrom}" - Repository is stored.
-#' If the Repository is stored in the main folder on the Github repository, this should be set 
+#' @param subdir While working with the remote repository. A character containing a name of
+#' a directory on the remote repository on which the "\code{repoFrom}" - Repository is stored.
+#' If the Repository is stored in the main folder on the remote repository, this should be set 
 #' to \code{FALSE} as default.
 #' 
 #' @note
-#' If \code{repo} and \code{user} are set to \code{NULL} (as default) in Github mode then global parameters
-#' set in \link{setGithubRepo} function are used. If one would like to copy whole Repository we suggest to 
+#' If \code{repo} and \code{user} are set to \code{NULL} (as default) in remote mode then global parameters
+#' set in \link{setRemoteRepo} function are used. If one would like to copy whole Repository we suggest to 
 #' extract all \code{md5hashes} in this way \code{unique(showLocalRepo(repoDir)[,1])}.
 #' 
 #' @author 
@@ -53,22 +54,22 @@
 #' \dontrun{
 #'
 #' 
-#' ## Using archiviist Github Repository to copy artifacts
+#' ## Using archivist remote Repository to copy artifacts
 #' # creating example Repository
 #'  
 #' exampleRepoDir <- tempfile()
-#' createEmptyRepo( exampleRepoDir )
+#' createLocalRepo( exampleRepoDir )
 #' 
 #' # Searching for md5hashes of artifacts (without data related to them)
-#' # in the archivist Github  Repository
-#' hashes <- searchInGithubRepo( pattern="name", user="pbiecek", repo="archivist", fixed=FALSE )
+#' # in the archivist remote  Repository
+#' hashes <- searchInRemoteRepo( pattern="name", user="pbiecek", repo="archivist", fixed=FALSE )
 #' 
-#' # Copying selected artifacts from archivist Github  Repository into exampleRepoDir Repository
+#' # Copying selected artifacts from archivist Remote  Repository into exampleRepoDir Repository
 #'
-#' copyGithubRepo( repoTo = exampleRepoDir , md5hashes= hashes, user="pbiecek", repo="archivist" )
+#' copyRemoteRepo( repoTo = exampleRepoDir , md5hashes= hashes, user="pbiecek", repo="archivist" )
 #' 
 #' # See how the gallery folder in our exampleRepoDir Repository
-#' # with copies of artifacts from archivist Github  Repository looks like
+#' # with copies of artifacts from archivist Remote  Repository looks like
 #' list.files( path = file.path( exampleRepoDir, "gallery" ) )
 #'
 #' # See how the backpack database in our exampleRepoDir Repository looks like
@@ -76,17 +77,17 @@
 #'
 #' # removing an example Repository
 #' 
-#' deleteRepo( exampleRepoDir, deleteRoot=TRUE )
+#' deleteLocalRepo( exampleRepoDir, deleteRoot=TRUE )
 #' 
 #' rm( exampleRepoDir )
 #' 
-#' # many archivist-like Repositories on one Github repository
+#' # many archivist-like Repositories on one Remote repository
 #' 
 #' dir <- paste0(getwd(), "/ex1")
-#' createEmptyRepo( dir )
-#' copyGithubRepo( repoTo = dir , md5hashes = "ff575c261c949d073b2895b05d1097c3",
+#' createLocalRepo( dir )
+#' copyRemoteRepo( repoTo = dir , md5hashes = "ff575c261c949d073b2895b05d1097c3",
 #'                 user="MarcinKosinski", repo="Museum",
-#'                 branch="master", repoDirGit="ex2")
+#'                 branch="master", subdir="ex2")
 #'                 
 #' # Check if the copied artifact is on our dir Repository
 #'
@@ -94,7 +95,7 @@
 #' list.files( path = file.path( dir, "gallery" ) ) # it is also in gallery folder
 #'
 #' # removing an example Repository
-#' deleteRepo( dir, TRUE)
+#' deleteLocalRepo( dir, TRUE)
 #'
 #' rm(dir)
 #' 
@@ -103,7 +104,7 @@
 #' # creating example Repository
 #'
 #' exampleRepoDir <- tempfile()
-#' createEmptyRepo( exampleRepoDir )
+#' createLocalRepo( exampleRepoDir )
 #'
 #' # Searching for md5hashes of artifacts (without data related to them)
 #' # in the graphGallery  Repository
@@ -115,7 +116,7 @@
 #'                              repoDir =  archivistRepo,
 #'                              fixed=FALSE )
 #' 
-#' # Copying selected artifacts from archivist Github  Repository into exampleRepoDir Repository
+#' # Copying selected artifacts from archivist Remote  Repository into exampleRepoDir Repository
 #'
 #' copyLocalRepo( repoFrom = archivistRepo, repoTo = exampleRepoDir , md5hashes= hashes )
 #'
@@ -124,7 +125,7 @@
 #' 
 #' # removing an example Repository
 #' 
-#' deleteRepo( exampleRepoDir, deleteRoot=TRUE )
+#' deleteLocalRepo( exampleRepoDir, deleteRoot=TRUE )
 #' 
 #' rm( exampleRepoDir )
 #' rm( archivistRepo )
@@ -149,29 +150,29 @@ copyLocalRepo <- function( repoFrom = NULL, repoTo, md5hashes ){
 
 #' @rdname copyToRepo
 #' @export
-copyGithubRepo <- function( repoTo, md5hashes, user = NULL, repo = NULL, branch="master", 
-                            repoDirGit = FALSE){
+copyRemoteRepo <- function( repoTo, md5hashes, repo = aoptions("repo"), user = aoptions("user"), branch = aoptions("branch"), subdir = aoptions("subdir"),
+                            repoType = aoptions("repoType")){
   stopifnot( is.character( c( repoTo, branch, md5hashes ) ),
              length(repoTo) == 1, length(branch) == 1, length(md5hashes) > 0)
 
-  GithubCheck( repo, user, repoDirGit ) # implemented in setRepo.R
+  RemoteRepoCheck( repo, user, branch, subdir, repoType) # implemented in setRepo.R
   
   repoTo <- checkDirectory( repoTo )
   
-  Temp <- downloadDB( repo, user, branch, repoDirGit )
+  remoteHook <- getRemoteHook(repo=repo, user=user, branch=branch, subdir=subdir, repoType=repoType)
+  Temp <- downloadDB( remoteHook )
   
-  on.exit(file.remove(Temp))
+  on.exit( unlink( Temp, recursive = TRUE, force = TRUE))
   
   copyRepo( repoTo = repoTo, repoFrom = Temp, md5hashes = md5hashes , 
-            local = FALSE, user = user, repo = repo, branch = branch, repoDirGit = repoDirGit )  
+            local = FALSE, user = user, repo = repo, branch = branch, subdir = subdir )  
   
   invisible(NULL)  
 }
 
-copyRepo <- function( repoFrom, repoTo, md5hashes, local = TRUE, user, repo, branch, repoDirGit ){
-  
+copyRepo <- function( repoFrom, repoTo, md5hashes, local = TRUE, user, repo, branch, subdir ){
   # clone artifact table
-  toInsertArtifactTable <- executeSingleQuery( dir = repoFrom, realDBname = local,
+  toInsertArtifactTable <- executeSingleQuery( dir = repoFrom, 
                       paste0( "SELECT DISTINCT * FROM artifact WHERE md5hash IN ",
                              "('", paste0( md5hashes, collapse="','"), "')" ) ) 
   
@@ -182,7 +183,7 @@ copyRepo <- function( repoFrom, repoTo, md5hashes, local = TRUE, user, repo, bra
                               x[2], "','",
                               x[3], "')" ) ) } )
   # clone tag table
-  toInsertTagTable <- executeSingleQuery( dir = repoFrom, realDBname = local,
+  toInsertTagTable <- executeSingleQuery( dir = repoFrom,
                                                paste0( "SELECT DISTINCT * FROM tag WHERE artifact IN ",
                                                        "('", paste0( md5hashes, collapse="','"), "')" ) ) 
   apply( toInsertTagTable, 1, function(x){
@@ -204,7 +205,7 @@ copyRepo <- function( repoFrom, repoTo, md5hashes, local = TRUE, user, repo, bra
     file.copy( from = file.path(repoFrom, "gallery", x), to = file.path( repoTo, "gallery" ),
           recursive = TRUE )})
   } else {
-    # if github mode
+    # if Remote mode
     # get files list
     options(RCurlOptions = list(cainfo = system.file("CurlSSL", "cacert.pem", package = "RCurl")))
 
@@ -215,14 +216,14 @@ copyRepo <- function( repoFrom, repoTo, md5hashes, local = TRUE, user, repo, bra
     
     filelist <- unlist(lapply(content(req)$tree, "[", "path"), use.names = F)
     
-    if( is.logical( repoDirGit ) ){
+    if( subdir == "/" ){
       whichFilesToClone <- grep("gallery/", filelist, value = TRUE, fixed = TRUE)
       needTidy <- strsplit(whichFilesToClone, "gallery/")
       whichFilesToClone <- unlist(lapply(needTidy, function(x){
         file.path("gallery", x[2])
       }))
     }else{
-      whichFilesToClone <- grep(paste0(repoDirGit,"/gallery/"), filelist, 
+      whichFilesToClone <- grep(paste0(subdir,"/gallery/"), filelist, 
                                 value = TRUE, fixed = TRUE)
     }
     
@@ -231,25 +232,25 @@ copyRepo <- function( repoFrom, repoTo, md5hashes, local = TRUE, user, repo, bra
     } ) ) ) #choose proper files from whole file list -whichFilesToClone
     
     # download files to gallery folder
-    lapply( filesToDownload, cloneGithubFile, repo = repo, user = user, branch = branch, 
-            to = repoTo, repoDirGit )
+    lapply( filesToDownload, cloneRemoteFile, repo = repo, user = user, branch = branch, 
+            to = repoTo, subdir )
   }
   invisible(NULL)
 }
 
-cloneGithubFile <- function( file, repo, user, branch, to, repoDirGit ){
+cloneRemoteFile <- function( file, repo, user, branch, to, subdir ){
 
     URLfile <- file.path( get( ".GithubURL", envir = .ArchivistEnv) , 
                        user, repo, branch, file) 
     # tidy
-    if ( is.character( repoDirGit ) ){
+    if (  subdir != "/" ){
       file <- paste0( "gallery/", strsplit(file, "gallery/")[[1]][2] )
     }
     
-    fileFromGithub <- getBinaryURL( URLfile )
+    fileFromRemote <- getBinaryURL( URLfile )
     
     file.create( file.path( to, file ) )
-    writeBin( fileFromGithub, file.path( to, file ) )
+    writeBin( fileFromRemote, file.path( to, file ) )
     #files contain "gallery/" in it's name
     
   }
