@@ -1,7 +1,7 @@
 test_that("split*Repo does not react on errors as it should and works as it's made to", {
   # Creating example default repository
   exampleRepoDir <- tempfile()
-  createEmptyRepo( exampleRepoDir, default = TRUE )
+  createLocalRepo( exampleRepoDir, default = TRUE )
   aoptions('silent', TRUE)
   # what about empty repo
   expect_error(splitTagsLocal())
@@ -13,7 +13,7 @@ test_that("split*Repo does not react on errors as it should and works as it's ma
   saveToRepo(d1,
              userTags = c(":", "", "\n", "\t", "\\", "\\\\"),
              repoDir = exampleRepoDir )
-  expect_equal(nrow(splitTagsLocal()), 14)
+  expect_equal(nrow(splitTagsLocal()), 18) # PBI: changed from 14. But this is not a good test, since with new extensions of list of tags it will fail.
   
   expect_equal(names(splitTagsLocal()), c('artifact', 'tagKey',
                                           'tagValue', 'createdDate'))
@@ -28,5 +28,5 @@ test_that("split*Repo does not react on errors as it should and works as it's ma
   expect_error(splitTagsLocal(1:100))
   expect_equal(ncol(splitTagsLocal()), 4)
   
-  deleteRepo(repoDir = exampleRepoDir, deleteRoot = TRUE)
+  deleteLocalRepo(repoDir = exampleRepoDir, deleteRoot = TRUE)
 })
\ No newline at end of file
